package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppLocation;
import com.ruoyi.app.domain.AppPmsOrderIn;
import com.ruoyi.app.domain.DTO.PmsStockInCompleteReq;
import com.ruoyi.app.service.IAppPmsOrderInService;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/pmsOrderIn")
public class AppPmsOrderInController extends BaseController
{
    @Autowired
    private IAppPmsOrderInService appPmsOrderInService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:in:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppPmsOrderIn.class)
    public TableDataInfo list(AppPmsOrderIn appPmsOrderIn)
    {
        startPage();
        List<AppPmsOrderIn> list = appPmsOrderInService.selectAppPmsOrderInList(appPmsOrderIn);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:in:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppPmsOrderIn appPmsOrderIn)
    {
        List<AppPmsOrderIn> list = appPmsOrderInService.selectAppPmsOrderInList(appPmsOrderIn);
        ExcelUtil<AppPmsOrderIn> util = new ExcelUtil<AppPmsOrderIn>(AppPmsOrderIn.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:in:query')")
    @GetMapping(value = "/{listId}")
    public AjaxResult getInfo(@PathVariable("listId") String listId)
    {
        return success(appPmsOrderInService.selectAppPmsOrderInByListId(listId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:in:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppPmsOrderIn appPmsOrderIn)
    {
        return toAjax(appPmsOrderInService.insertAppPmsOrderIn(appPmsOrderIn));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:in:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppPmsOrderIn appPmsOrderIn)
    {
        return toAjax(appPmsOrderInService.updateAppPmsOrderIn(appPmsOrderIn));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:in:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{listIds}")
    public AjaxResult remove(@PathVariable String[] listIds)
    {
        return toAjax(appPmsOrderInService.deleteAppPmsOrderInByListIds(listIds));
    }


}
